@@ -1,11 +1,12 @@
 // Note: This module is called `structbuf` in contrast to `struct` in the C++
 // implementation, since Rust does not allow module names to be one of the
 // language keywords.
-use crate::archive::Struct;
-use crate::memory;
+use crate::{
+    memory,
+    structs::{NoOverlap, RefFactory, Struct},
+};
 
-use std::fmt;
-use std::marker;
+use std::{fmt, marker};
 
 /// A container holding a single flatdata struct in memory, and providing read
 /// and write access to it.
@@ -18,27 +19,48 @@ use std::marker;
 /// buffer.
 ///
 /// # Examples
+/// ``` flatdata
+/// struct A {
+///     x : u32 : 16;
+///     y : u32 : 16;
+/// }
+///
+/// archive X {
+///    data : A;
+/// }
+/// ```
 ///
 /// ```
 /// # #[macro_use] extern crate flatdata;
 /// # fn main() {
-/// use flatdata::StructBuf;
-///
-/// define_struct!(
-///     A,
-///     RefA,
-///     RefMutA,
-///     "no_schema",
-///     4,
-///     (x, set_x, u32, 0, 16),
-///     (y, set_y, u32, 16, 16)
-/// );
-///
+/// # use flatdata::{ MemoryResourceStorage, Archive, ArchiveBuilder, StructBuf };
+/// #
+/// # define_struct!(
+/// #     A,
+/// #     RefA,
+/// #     RefMutA,
+/// #     "schema of A",
+/// #     4,
+/// #     (x, set_x, u32, u32, 0, 16),
+/// #     (y, set_y, u32, u32, 16, 16));
+/// #
+/// # define_archive!(X, XBuilder, "schema of X";
+/// #     struct(data, false, "schema of data", set_data, A),
+/// # );
+/// #
+/// let storage = MemoryResourceStorage::new("/root/structbuf");
+/// let builder = XBuilder::new(storage.clone()).expect("failed to create builder");
 /// let mut a = StructBuf::<A>::new();
 /// a.get_mut().set_x(1);
 /// a.get_mut().set_y(2);
-/// assert_eq!(a.get().x(), 1);
-/// assert_eq!(a.get().y(), 2);
+/// builder.set_data(a.get());
+///
+/// println!("{:?}", storage);
+/// let archive = X::open(storage).expect("failed to open");
+/// let view = archive.data();
+///
+/// assert_eq!(view.x(), 1);
+/// assert_eq!(view.y(), 2);
 /// # }
 /// ```
 ///
@@ -46,7 +68,7 @@ use std::marker;
 /// [coappearances]: https://github.com/boxdot/flatdata-rs/blob/master/tests/coappearances_test.rs#L183
 pub struct StructBuf<T>
 where
-    T: for<'a> Struct<'a>,
+    T: RefFactory + NoOverlap,
 {
     data: Vec<u8>,
     _phantom: marker::PhantomData<T>,
@@ -54,7 +76,7 @@ where
 
 impl<T> StructBuf<T>
 where
-    T: for<'a> Struct<'a>,
+    T: RefFactory + NoOverlap,
 {
     /// Creates an empty struct buffer.
     ///
@@ -85,7 +107,7 @@ where
 
 impl<T> fmt::Debug for StructBuf<T>
 where
-    T: for<'a> Struct<'a>,
+    T: RefFactory + NoOverlap,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f, "StructBuf {{ resource: {:?} }}", self.get())
@@ -94,7 +116,7 @@ where
 
 impl<T> Default for StructBuf<T>
 where
-    T: for<'a> Struct<'a>,
+    T: RefFactory + NoOverlap,
 {
     fn default() -> Self {
         Self::new()
@@ -103,7 +125,7 @@ where
 
 impl<T> AsRef<[u8]> for StructBuf<T>
 where
-    T: for<'a> Struct<'a>,
+    T: RefFactory + NoOverlap,
 {
     fn as_ref(&self) -> &[u8] {
         self.as_bytes()
@@ -121,8 +143,8 @@ mod test {
         RefMutA,
         "no_schema",
         4,
-        (x, set_x, u32, 0, 16),
-        (y, set_y, u32, 16, 16)
+        (x, set_x, u32, u32, 0, 16),
+        (y, set_y, u32, u32, 16, 16)
     );
 
     #[test]
